==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/EncryptionPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.EncryptionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property identity The identity that will be used to access the key vault for encryption at rest.
 * @property keyVaultProperties Customer Key vault properties.
 * @property status Indicates whether or not the encryption is enabled for the workspace.
 */
public data class EncryptionPropertyArgs(
    public val identity: Output<IdentityForCmkArgs>? = null,
    public val keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>,
    public val status: Output<Either<String, EncryptionStatus>>,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs.builder()
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .keyVaultProperties(
                keyVaultProperties.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .status(
                status.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [EncryptionPropertyArgs].
 */
@PulumiTagMarker
public class EncryptionPropertyArgsBuilder internal constructor() {
    private var identity: Output<IdentityForCmkArgs>? = null

    private var keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>? = null

    private var status: Output<Either<String, EncryptionStatus>>? = null

    /**
     * @param value The identity that will be used to access the key vault for encryption at rest.
     */
    @JvmName("qbmxkcktvkrvwnmd")
    public suspend fun identity(`value`: Output<IdentityForCmkArgs>) {
        this.identity = value
    }

    /**
     * @param value Customer Key vault properties.
     */
    @JvmName("fpnauamlgeeugbkj")
    public suspend fun keyVaultProperties(`value`: Output<EncryptionKeyVaultPropertiesArgs>) {
        this.keyVaultProperties = value
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("gktwwemsynuydlbb")
    public suspend fun status(`value`: Output<Either<String, EncryptionStatus>>) {
        this.status = value
    }

    /**
     * @param value The identity that will be used to access the key vault for encryption at rest.
     */
    @JvmName("oalumacemqvfwoic")
    public suspend fun identity(`value`: IdentityForCmkArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument The identity that will be used to access the key vault for encryption at rest.
     */
    @JvmName("ufvosbaqnybvgjdq")
    public suspend fun identity(argument: suspend IdentityForCmkArgsBuilder.() -> Unit) {
        val toBeMapped = IdentityForCmkArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value Customer Key vault properties.
     */
    @JvmName("jyejwcnnacsrhmil")
    public suspend fun keyVaultProperties(`value`: EncryptionKeyVaultPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyVaultProperties = mapped
    }

    /**
     * @param argument Customer Key vault properties.
     */
    @JvmName("udtkhepomeotywsb")
    public suspend
    fun keyVaultProperties(argument: suspend EncryptionKeyVaultPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionKeyVaultPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyVaultProperties = mapped
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("dognfvfcybxskebw")
    public suspend fun status(`value`: Either<String, EncryptionStatus>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("mjqdbresdasdqtji")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncryptionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("xxqqkubuwyupifec")
    public fun status(`value`: EncryptionStatus) {
        val toBeMapped = Either.ofRight<String, EncryptionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): EncryptionPropertyArgs = EncryptionPropertyArgs(
        identity = identity,
        keyVaultProperties = keyVaultProperties ?: throw PulumiNullFieldException("keyVaultProperties"),
        status = status ?: throw PulumiNullFieldException("status"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/EncryptionPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.EncryptionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property identity The identity that will be used to access the key vault for encryption at rest.
 * @property keyVaultProperties Customer Key vault properties.
 * @property status Indicates whether or not the encryption is enabled for the workspace.
 */
public data class EncryptionPropertyArgs(
    public val identity: Output<IdentityForCmkArgs>? = null,
    public val keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>,
    public val status: Output<Either<String, EncryptionStatus>>,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.EncryptionPropertyArgs.builder()
            .identity(identity?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .keyVaultProperties(
                keyVaultProperties.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .status(
                status.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [EncryptionPropertyArgs].
 */
@PulumiTagMarker
public class EncryptionPropertyArgsBuilder internal constructor() {
    private var identity: Output<IdentityForCmkArgs>? = null

    private var keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>? = null

    private var status: Output<Either<String, EncryptionStatus>>? = null

    /**
     * @param value The identity that will be used to access the key vault for encryption at rest.
     */
    @JvmName("pxluoppamyqeymwy")
    public suspend fun identity(`value`: Output<IdentityForCmkArgs>) {
        this.identity = value
    }

    /**
     * @param value Customer Key vault properties.
     */
    @JvmName("cuediffproasrqkm")
    public suspend fun keyVaultProperties(`value`: Output<EncryptionKeyVaultPropertiesArgs>) {
        this.keyVaultProperties = value
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("xphonqwdhhgjbuqc")
    public suspend fun status(`value`: Output<Either<String, EncryptionStatus>>) {
        this.status = value
    }

    /**
     * @param value The identity that will be used to access the key vault for encryption at rest.
     */
    @JvmName("uytndrvsxcjhslcw")
    public suspend fun identity(`value`: IdentityForCmkArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identity = mapped
    }

    /**
     * @param argument The identity that will be used to access the key vault for encryption at rest.
     */
    @JvmName("iekpafdtsobbatii")
    public suspend fun identity(argument: suspend IdentityForCmkArgsBuilder.() -> Unit) {
        val toBeMapped = IdentityForCmkArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.identity = mapped
    }

    /**
     * @param value Customer Key vault properties.
     */
    @JvmName("apbriwtsbscrtmwj")
    public suspend fun keyVaultProperties(`value`: EncryptionKeyVaultPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.keyVaultProperties = mapped
    }

    /**
     * @param argument Customer Key vault properties.
     */
    @JvmName("dootqdlyfsjnrnbw")
    public suspend
    fun keyVaultProperties(argument: suspend EncryptionKeyVaultPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionKeyVaultPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyVaultProperties = mapped
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("oxolgaouuosidaqk")
    public suspend fun status(`value`: Either<String, EncryptionStatus>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("wwqfemmyshwqmwrs")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncryptionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether or not the encryption is enabled for the workspace.
     */
    @JvmName("bqlqnbyauwwbdewg")
    public fun status(`value`: EncryptionStatus) {
        val toBeMapped = Either.ofRight<String, EncryptionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): EncryptionPropertyArgs = EncryptionPropertyArgs(
        identity = identity,
        keyVaultProperties = keyVaultProperties ?: throw PulumiNullFieldException("keyVaultProperties"),
        status = status ?: throw PulumiNullFieldException("status"),
    )
}
